@@ -1,9 +1,16 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+from typing import TYPE_CHECKING
+
 import numpy as np
 
 from .numpy import unblock
 
+if TYPE_CHECKING:
+	from typing import Union, Tuple
+	from fractions import Fraction
+	Rational = Union[float, Fraction]
+
 def grayscale(arr):
 	return np.sum(arr, axis=-1) // arr.shape[-1]
 
@@ -17,14 +24,14 @@ def histogram_1d(arr, levels):
 	return np.apply_along_axis(np.bincount, -1, arr, minlength=levels)
 
 def resize_oar(max_width, max_height, dar):
-	# type: (int, int, Union[float, Fraction]) -> Tuple[int, int]
+	# type: (int, int, Rational) -> Tuple[int, int]
 
 	maxdar = max_width / max_height
 
-	if dar >= maxdar: # wider than it should be
+	if dar >= maxdar:  # wider than it should be
 		width = max_width
 		height = int(width / dar)
-	else: # thinner than it should be
+	else:  # thinner than it should be
 		height = max_height
 		width = int(height * dar)
 
@@ -33,7 +40,7 @@ def resize_oar(max_width, max_height, dar):
 def resize_maxsize(max_width, max_height, width, height):
 	# type: (int, int, int, int) -> Tuple[int, int]
 
-	return resize_oar(max_width, max_height, width / heigh)
+	return resize_oar(max_width, max_height, width / height)
 
 def histogram_2d(arr, levels):
 	# type: (np.ndarray, int) -> np.ndarray
