@@ -5,8 +5,9 @@ from typing import TYPE_CHECKING
 from .func import identity
 
 if TYPE_CHECKING:
-	from typing import Callable, Optional
+	from typing import Callable, Optional, List, TypeVar
 	from pandas import DataFrame
+	T = TypeVar("T")
 
 def strlist(sep):
 	# type: (str, ) -> Callable[[str], List[str]]
@@ -19,8 +20,8 @@ def strlist(sep):
 
 	return inner
 
-def dataframe_to_dict(df, empty=False, cellfunc=None):
-	# type: (DataFrame, bool, Optional[Callable]) -> dict
+def dataframe_to_dict(df, empty=False, cellfunc=None, dictcls=dict):
+	# type: (DataFrame, bool, Optional[Callable], Callable[[Iterable[Tuple[str, Any]]], T]) -> T
 
 	""" Turns dataframes into trees. Columns first, then rows
 	"""
@@ -36,8 +37,8 @@ def dataframe_to_dict(df, empty=False, cellfunc=None):
 
 	def rows(df):
 		for colname, coldata in df.iteritems():
-			value = dict(cols(coldata))
+			value = dictcls(cols(coldata))
 			if value or empty:
 				yield colname, value
 
-	return dict(rows(df))
+	return dictcls(rows(df))
